@@ -14,7 +14,7 @@
 
 import json
 from datetime import timedelta
-from typing import Any
+from typing import Any, Optional
 
 from robot.utils import DotDict  # type: ignore
 
@@ -26,7 +26,9 @@ from ..utils import DownloadedFile, keyword, logger
 class Evaluation(LibraryComponent):
     @keyword(name="Execute JavaScript", tags=("Setter", "Getter", "PageContent"))
     def execute_javascript(self, function: str, selector: str = "") -> Any:
-        """Executes given javascript on the page.
+        """*DEPRECATED!!* Use keyword `Evaluate JavaScript` instead.
+
+        Executes given javascript on the page.
 
         ``function`` A valid javascript function or a javascript function body. For example
         ``() => true`` and ``true`` will behave similarly.
@@ -36,6 +38,14 @@ class Evaluation(LibraryComponent):
         to capture the elementhandle. For example ``(element) => document.activeElement === element``
         See the `Finding elements` section for details about the selectors.
 
+        Same functionality can be replaced with newer ``Evaluate JavaScript`` Keyword:
+        | -    Execute JavaScript    (elem) => elem.innerText = "abc"    h1
+        | +    Evaluate JavaScript    h1    (elem) => elem.innerText = "abc"
+
+        Example for replacement without Selector:
+        | -    Execute JavaScript    () => document.location.hostname
+        | +    Evaluate JavaScript    ${None}    () => document.location.hostname
+
         Keyword uses strict mode if selector is defined. See `Finding elements` for more details
         about strict mode.
 
@@ -53,6 +63,66 @@ class Evaluation(LibraryComponent):
             return json.loads(response.result)
         return response.result
 
+    @keyword(name="Evaluate JavaScript", tags=("Setter", "Getter", "PageContent"))
+    def evaluate_javascript(
+        self,
+        selector: Optional[str] = None,
+        *function: str,
+        arg: Any = None,
+        all_elements: bool = False,
+    ) -> Any:
+        """Executes given javascript on the selected element(s) or on page.
+
+        ``selector`` Selector to resolve and pass to the JavaScript function. This will be the first
+        argument the function receives if not ``${None}``. ``selector`` is optional and can be omitted.
+        If given a selector, a function is necessary, with an argument
+        to capture the elementHandle. For example ``(element) => document.activeElement === element``
+        See the `Finding elements` section for details about the selectors.
+
+        ``*function`` A valid javascript function or a javascript function body.
+        These arguments can be used to write readable multiline JavaScript.
+
+        ``arg`` an additional argument that can be handed over to the JavaScript function.
+        This argument must be JSON serializable. ElementHandles are not supported.
+
+        ``all_elements`` defines if only the single elementHandle found by ``selector`` is handed
+        over to the function or if set to ``True`` all found elements are handed over as array.
+
+        Example with ``all_elements=True``:
+        |  ${texts}=    Evaluate JavaScript    button
+        |  ...    (elements, arg) => {
+        |  ...        let text = []
+        |  ...            for (e of elements) {
+        |  ...                console.log(e.innerText)
+        |  ...                text.push(e.innerText)
+        |  ...            }
+        |  ...        text.push(arg)
+        |  ...        return text
+        |  ...    }
+        |  ...    all_elements=True
+        |  ...    arg=Just another Text
+
+        Keyword uses strict mode if ``all_elements`` is ``False``. See `Finding elements` for more details
+        about strict mode.
+
+        [https://github.com/MarketSquare/robotframework-browser/tree/main/atest/test/06_Examples/js_evaluation.robot | Usage examples. ]
+        """
+        with self.playwright.grpc_channel() as stub:
+            response = stub.EvaluateJavascript(
+                Request().EvaluateAll(
+                    selector=selector or "",
+                    script="\n".join(function),
+                    arg=json.dumps(arg),
+                    allElements=all_elements,
+                    strict=self.strict_mode,
+                )
+            )
+        if response.log:
+            logger.info(response.log)
+        if response.result:
+            return json.loads(response.result)
+        return response.result
+
     @keyword(tags=("Setter", "PageContent"))
     def highlight_elements(
         self,
